@@ -88,7 +88,8 @@ class WebhookRequest(BaseModel):
     headers: Optional[dict]
 
 class ErrorResponse(BaseModel):
-    response: requests.models.Response
+    status_code: int
+    detail: Optional[str]
     message: str
         
     class Config:
